@@ -53,9 +53,8 @@ setMethod("subset", signature(x = "Speclib"),
     stop("'subset' must evaluate to logical")
   r <- r & !is.na(r)
   
+  id_speclib <- as.character(idSpeclib(x))[r]
   spectra(x) <- if (sum(r) == 1) matrix(data=spectra(x)[r,], nrow=1) else spectra(x)[r,]
-  
-  idSpeclib(x) <- as.character(idSpeclib(x)[r])
 
   if (nrow(attribute(x)) == nrow(target))
     attribute(x) <- attribute(x)[r,] 
@@ -66,6 +65,7 @@ setMethod("subset", signature(x = "Speclib"),
   } else {
     usagehistory(x) <- "Subset of spectra"
   }
+  idSpeclib(x) <- id_speclib
   return(x)
 }
 
