@@ -345,75 +345,7 @@ plot(sp_summer, FUN = "mean", col = "darkred", new = FALSE)
 
 
 ###################################################
-### code chunk number 34: Hsdar-intro.Rnw:525-526 (eval = FALSE)
-###################################################
-## plot(spectral_data, FUN = 1, subset = c(1200,1300)) #raw spectrum
-
-
-###################################################
-### code chunk number 35: Hsdar-intro.Rnw:529-531
-###################################################
-par(mar = c(4,4,0.1,0.1), cex = 0.75)
-plot(spectral_data, FUN = 1, subset = c(1200,1300)) #raw spectrum
-
-
-###################################################
-### code chunk number 36: Hsdar-intro.Rnw:539-547
-###################################################
-#
-#Filter Speclib:
-#
-sgolay <- smoothSpeclib(spectral_data, method = "sgolay", n = 25)
-lowess <- smoothSpeclib(spectral_data, method = "lowess", f = .01)
-meanflt <- smoothSpeclib(spectral_data, method = "mean", p = 5)
-spline <- smoothSpeclib(spectral_data, method = "spline", 
-                         n = round(nbands(spectral_data)/10, 0))
-
-
-###################################################
-### code chunk number 37: Hsdar-intro.Rnw:553-569 (eval = FALSE)
-###################################################
-## par(mfrow = c(2,2))
-## plot(sgolay, FUN = 1, subset = c(1200,1300), col = "red",
-## main = "Savitzky-Golay-Filter")
-## plot(spectral_data, FUN = 1, new = FALSE) #raw spectrum
-## 
-## plot(lowess, FUN = 1, subset = c(1200,1300), col = "red",
-## main = "Lowess-Filter")
-## plot(spectral_data, FUN = 1, new = FALSE) #raw spectrum
-## 
-## plot(meanflt, FUN = 1, subset = c(1200,1300), col = "red",
-## main = "Mean-filter")
-## plot(spectral_data, FUN = 1, new = FALSE) #raw spectrum
-## 
-## plot(spline, FUN = 1, subset = c(1200,1300), col = "red",
-## main = "Spline-Filter")
-## plot(spectral_data, FUN = 1, new = FALSE) #raw spectrum
-
-
-###################################################
-### code chunk number 38: Hsdar-intro.Rnw:572-588
-###################################################
-par(mfrow=c(2,2), mar = c(4,4,3,0.1), cex = 0.75)
-plot(sgolay, FUN = 1, subset = c(1200,1300), col = "red",
-main = "Savitzky-Golay-Filter")
-plot(spectral_data, FUN = 1, new = FALSE) #raw spectrum
-
-plot(lowess, FUN = 1, subset = c(1200,1300), col = "red",
-main = "Lowess-Filter")
-plot(spectral_data, FUN = 1, new = FALSE) #raw spectrum
-
-plot(meanflt, FUN = 1, subset = c(1200,1300), col = "red",
-main = "Mean-filter")
-plot(spectral_data, FUN = 1, new = FALSE) #raw spectrum
-
-plot(spline, FUN = 1, subset = c(1200,1300), col = "red",
-main = "Spline-Filter")
-plot(spectral_data, FUN = 1, new = FALSE) #raw spectrum
-
-
-###################################################
-### code chunk number 39: Hsdar-intro.Rnw:601-609
+### code chunk number 34: Hsdar-intro.Rnw:526-534
 ###################################################
 spectral_data_masked <- spectral_data
 mask(spectral_data_masked) <- c(1040,1060,1300,1450)
@@ -426,7 +358,7 @@ plot(spectral_data_masked, FUN = 1)
 
 
 ###################################################
-### code chunk number 40: Hsdar-intro.Rnw:612-615
+### code chunk number 35: Hsdar-intro.Rnw:537-540
 ###################################################
 par(mfrow=c(1,2), mar = c(4,4,0.1,0.1), cex = 0.75)
 plot(spectral_data, FUN = 1)
@@ -434,79 +366,165 @@ plot(spectral_data_masked, FUN = 1)
 
 
 ###################################################
-### code chunk number 41: Hsdar-intro.Rnw:624-626
+### code chunk number 36: Hsdar-intro.Rnw:549-551
 ###################################################
 spectral_data_interpolated <- interpolate.mask(spectral_data_masked)
 plot(spectral_data_interpolated, FUN = 1)
 
 
 ###################################################
-### code chunk number 42: Hsdar-intro.Rnw:629-631
+### code chunk number 37: Hsdar-intro.Rnw:554-556
 ###################################################
 par(mar = c(4,4,0,0.1), cex = 0.75)
 plot(spectral_data_interpolated, FUN = 1)
 
 
 ###################################################
-### code chunk number 43: Hsdar-intro.Rnw:640-650
+### code chunk number 38: Hsdar-intro.Rnw:560-561
+###################################################
+spectral_data <- spectral_data_masked
+
+
+###################################################
+### code chunk number 39: Hsdar-intro.Rnw:569-570 (eval = FALSE)
+###################################################
+## plot(spectral_data, FUN = 1, subset = c(1200,1300)) #raw spectrum
+
+
+###################################################
+### code chunk number 40: Hsdar-intro.Rnw:573-575
+###################################################
+par(mar = c(4,4,0.1,0.1), cex = 0.75)
+plot(spectral_data, FUN = 1, subset = c(1200,1300)) #raw spectrum
+
+
+###################################################
+### code chunk number 41: Hsdar-intro.Rnw:583-591
+###################################################
+#
+#Filter Speclib:
+#
+sgolay <- smoothSpeclib(spectral_data, method = "sgolay", n = 25)
+lowess <- smoothSpeclib(spectral_data, method = "lowess", f = .01)
+meanflt <- smoothSpeclib(spectral_data, method = "mean", p = 5)
+spline <- smoothSpeclib(spectral_data, method = "spline", 
+                         n = round(nbands(spectral_data)/10, 0))
+
+
+###################################################
+### code chunk number 42: Hsdar-intro.Rnw:597-613 (eval = FALSE)
+###################################################
+## par(mfrow = c(2,2))
+## plot(sgolay, FUN = 1, subset = c(1200,1300), col = "red",
+##      main = "Savitzky-Golay-Filter")
+## plot(spectral_data, FUN = 1, new = FALSE) #raw spectrum
+## 
+## plot(lowess, FUN = 1, subset = c(1200,1300), col = "red",
+##      main = "Lowess-Filter")
+## plot(spectral_data, FUN = 1, new = FALSE) #raw spectrum
+## 
+## plot(meanflt, FUN = 1, subset = c(1200,1300), col = "red",
+##      main = "Mean-filter")
+## plot(spectral_data, FUN = 1, new = FALSE) #raw spectrum
+## 
+## plot(spline, FUN = 1, subset = c(1200,1300), col = "red",
+##      main = "Spline-Filter")
+## plot(spectral_data, FUN = 1, new = FALSE) #raw spectrum
+
+
+###################################################
+### code chunk number 43: Hsdar-intro.Rnw:616-632
+###################################################
+par(mfrow=c(2,2), mar = c(4,4,3,0.1), cex = 0.75)
+plot(sgolay, FUN = 1, subset = c(1200,1300), col = "red",
+     main = "Savitzky-Golay-Filter")
+plot(spectral_data, FUN = 1, new = FALSE) #raw spectrum
+
+plot(lowess, FUN = 1, subset = c(1200,1300), col = "red",
+     main = "Lowess-Filter")
+plot(spectral_data, FUN = 1, new = FALSE) #raw spectrum
+
+plot(meanflt, FUN = 1, subset = c(1200,1300), col = "red",
+     main = "Mean-filter")
+plot(spectral_data, FUN = 1, new = FALSE) #raw spectrum
+
+plot(spline, FUN = 1, subset = c(1200,1300), col = "red",
+     main = "Spline-Filter")
+plot(spectral_data, FUN = 1, new = FALSE) #raw spectrum
+
+
+###################################################
+### code chunk number 44: Hsdar-intro.Rnw:643-662
 ###################################################
 spectral_data_1deriv <- derivative.speclib(spectral_data, m = 1)
 spectral_data_2deriv <- derivative.speclib(spectral_data, m = 2)
+
+## Get index of red edge wavelength
+redEdgePart <- wavelength(spectral_data_2deriv) >= 600 & 
+               wavelength(spectral_data_2deriv) <= 800
+               
+## Cut spectra to red edge
+spectral_data_1deriv <- spectral_data_1deriv[,redEdgePart]
+spectral_data_2deriv <- spectral_data_2deriv[,redEdgePart]
+  
 #
 #plot derivations of the red edge area of 1. spectrum in the Speclib:
 #
 par(mfrow=c(1,2))
-plot(spectral_data_1deriv, FUN = 1, subset = c(600,800),
-main = "First derivation")
-plot(spectral_data_2deriv, FUN = 1, subset = c(600,800),
-main = "Second Derivation")
+plot(spectral_data_1deriv, FUN = 1, xlim = c(600,800),
+     main = "First derivation")
+plot(spectral_data_2deriv, FUN = 1, xlim = c(600,800),
+     main = "Second Derivation")
 
 
 ###################################################
-### code chunk number 44: Hsdar-intro.Rnw:653-658
+### code chunk number 45: Hsdar-intro.Rnw:665-670
 ###################################################
 par(mfrow = c(1,2), mar = c(4,4,3,0.1), cex = 0.75)
-plot(spectral_data_1deriv, FUN = 1, subset = c(600,800),
-main = "First derivation")
-plot(spectral_data_2deriv, FUN = 1, subset = c(600,800),
-main = "Second Derivation")
+plot(spectral_data_1deriv, FUN = 1, xlim = c(600,800),
+     main = "First derivation")
+plot(spectral_data_2deriv, FUN = 1, xlim = c(600,800),
+     main = "Second Derivation")
 
 
 ###################################################
-### code chunk number 45: Hsdar-intro.Rnw:665-677
+### code chunk number 46: Hsdar-intro.Rnw:677-689
 ###################################################
 spectral_data_1deriv <- derivative.speclib(smoothSpeclib(
-spectral_data, method = "sgolay", n = 35), m = 1)
+  spectral_data, method = "sgolay", n = 35), m = 1)
 spectral_data_2deriv <- derivative.speclib(smoothSpeclib(
-spectral_data, method = "sgolay", n = 35), m = 2)
+  spectral_data, method = "sgolay", n = 35), m = 2)
 #
 #Plot results:
 #
 par(mfrow=c(1,2))
-plot(spectral_data_1deriv, FUN = 1, subset = c(600,800),
-main = "First derivation")
-plot(spectral_data_2deriv, FUN = 1, subset = c(600,800),
-main = "Second Derivation")
+plot(spectral_data_1deriv, FUN = 1, xlim = c(600,800),
+     main = "First derivation")
+plot(spectral_data_2deriv, FUN = 1, xlim = c(600,800),
+     main = "Second Derivation")
 
 
 ###################################################
-### code chunk number 46: Hsdar-intro.Rnw:680-685
+### code chunk number 47: Hsdar-intro.Rnw:692-700
 ###################################################
+## Cut spectra to red edge
+spectral_data_1deriv <- spectral_data_1deriv[,redEdgePart]
+spectral_data_2deriv <- spectral_data_2deriv[,redEdgePart]
 par(mfrow = c(1,2), mar = c(4,4,3,0.1), cex = 0.75)
-plot(spectral_data_1deriv, FUN = 1, subset = c(600,800),
-main = "First derivation")
-plot(spectral_data_2deriv, FUN = 1, subset = c(600,800),
-main = "Second Derivation")
+plot(spectral_data_1deriv, FUN = 1, xlim = c(600,800),
+     main = "First derivation")
+plot(spectral_data_2deriv, FUN = 1, xlim = c(600,800),
+     main = "Second Derivation")
 
 
 ###################################################
-### code chunk number 47: Hsdar-intro.Rnw:694-695
+### code chunk number 48: Hsdar-intro.Rnw:709-710
 ###################################################
 get.sensor.characteristics(0)
 
 
 ###################################################
-### code chunk number 48: Hsdar-intro.Rnw:702-705
+### code chunk number 49: Hsdar-intro.Rnw:717-720
 ###################################################
 ## use spectral response function
 spectral_data_resampled <- spectralResampling(spectral_data, 
@@ -514,7 +532,7 @@ spectral_data_resampled <- spectralResampling(spectral_data,
 
 
 ###################################################
-### code chunk number 49: Hsdar-intro.Rnw:710-715
+### code chunk number 50: Hsdar-intro.Rnw:725-730
 ###################################################
 spectral_data_resampled
 wavelength(spectral_data_resampled)
@@ -524,29 +542,29 @@ plot(spectral_data_resampled)
 
 
 ###################################################
-### code chunk number 50: Hsdar-intro.Rnw:718-720
+### code chunk number 51: Hsdar-intro.Rnw:733-735
 ###################################################
 par(mar = c(4,4,0.1,0.1), cex = 0.75)
 plot(spectral_data_resampled)
 
 
 ###################################################
-### code chunk number 51: Hsdar-intro.Rnw:736-740
+### code chunk number 52: Hsdar-intro.Rnw:751-755
 ###################################################
 data(spectral_data)
 spectral_data_preproc <- smoothSpeclib(spectral_data, 
-method = "sgolay", n = 5)
-#mask(spectral_data_preproc) <- c(1040,1060,1300,1450)
+                                       method = "sgolay", n = 5)
+mask(spectral_data_preproc) <- c(1040,1060,1300,1450)
 
 
 ###################################################
-### code chunk number 52: Hsdar-intro.Rnw:745-746
+### code chunk number 53: Hsdar-intro.Rnw:760-761
 ###################################################
 str(transformSpeclib)
 
 
 ###################################################
-### code chunk number 53: Hsdar-intro.Rnw:756-768
+### code chunk number 54: Hsdar-intro.Rnw:771-783
 ###################################################
 #convex hull:
 ch_cline <- transformSpeclib(spectral_data_preproc[16:30,],
@@ -563,7 +581,7 @@ sh_bd <- transformSpeclib(spectral_data_preproc,
 
 
 ###################################################
-### code chunk number 54: Hsdar-intro.Rnw:773-782 (eval = FALSE)
+### code chunk number 55: Hsdar-intro.Rnw:788-797 (eval = FALSE)
 ###################################################
 ## #plot results for the first spectrum:
 ## #
@@ -577,7 +595,7 @@ sh_bd <- transformSpeclib(spectral_data_preproc,
 
 
 ###################################################
-### code chunk number 55: Hsdar-intro.Rnw:785-792
+### code chunk number 56: Hsdar-intro.Rnw:800-807
 ###################################################
 par(mfrow=c(2,2), mar = c(4,4,3,0.1), cex = 0.75)
 plot(ch_cline, ispec = 1, numeratepoints = FALSE,
@@ -589,7 +607,7 @@ plot(sh_bd, ispec = 1, main = "Segmented hull - Band depth")
 
 
 ###################################################
-### code chunk number 56: Hsdar-intro.Rnw:801-806 (eval = FALSE)
+### code chunk number 57: Hsdar-intro.Rnw:816-821 (eval = FALSE)
 ###################################################
 ## par(mfrow = c(1,2))
 ## plot(sh_cline, ispec = 1, main = "Continuum line, Spectrum 1",
@@ -599,7 +617,7 @@ plot(sh_bd, ispec = 1, main = "Segmented hull - Band depth")
 
 
 ###################################################
-### code chunk number 57: Hsdar-intro.Rnw:809-814
+### code chunk number 58: Hsdar-intro.Rnw:824-829
 ###################################################
 par(mfrow=c(1,2), mar = c(4,4,3,0.1), cex = 0.75)
 plot(sh_cline, ispec = 1, main = "Continuum line, Spectrum 1",
@@ -609,75 +627,81 @@ plot(sh_cline, ispec = 5, main = "Continuum line, Spectrum 5",
 
 
 ###################################################
-### code chunk number 58: Hsdar-intro.Rnw:830-831
+### code chunk number 59: Hsdar-intro.Rnw:845-846
 ###################################################
 str(deletecp)
 
 
 ###################################################
-### code chunk number 59: Hsdar-intro.Rnw:836-840
+### code chunk number 60: Hsdar-intro.Rnw:851-855
 ###################################################
 getcp(sh_cline, 1, subset = c(500, 700)) #see all points
 sh_cline <- deletecp(sh_cline, 1, 
-                     c(580:700)) #delete all between 580 and 700 nm
+                     c(500:700)) #delete all between 500 and 700 nm
 getcp(sh_cline, 1, subset = c(500, 700)) #see what happened
 
 
 ###################################################
-### code chunk number 60: Hsdar-intro.Rnw:845-846
+### code chunk number 61: Hsdar-intro.Rnw:860-861
 ###################################################
 #sh_cline <- addcp(sh_cline, 1, 460)
 
 
 ###################################################
-### code chunk number 61: Hsdar-intro.Rnw:852-853
+### code chunk number 62: Hsdar-intro.Rnw:867-868
 ###################################################
 checkhull(sh_cline, 1)$error
 
 
 ###################################################
-### code chunk number 62: Hsdar-intro.Rnw:858-859
+### code chunk number 63: Hsdar-intro.Rnw:873-874
 ###################################################
-sh_cline <- addcp(sh_cline, 1, 317)
+sh_cline <- addcp(sh_cline, 1, 1060)
 
 
 ###################################################
-### code chunk number 63: Hsdar-intro.Rnw:864-865
+### code chunk number 64: Hsdar-intro.Rnw:879-880
+###################################################
+checkhull(sh_cline, 1)$error
+
+
+###################################################
+### code chunk number 65: Hsdar-intro.Rnw:885-886
 ###################################################
 sh_clineUpdate <- makehull(sh_cline, 1) #update the hull of spectrum 1
 
 
 ###################################################
-### code chunk number 64: Hsdar-intro.Rnw:871-872
+### code chunk number 66: Hsdar-intro.Rnw:892-893
 ###################################################
 sh_bd <- updatecl(sh_bd, sh_clineUpdate) #update the band depth
 
 
 ###################################################
-### code chunk number 65: Hsdar-intro.Rnw:878-885 (eval = FALSE)
+### code chunk number 67: Hsdar-intro.Rnw:899-906 (eval = FALSE)
 ###################################################
 ## #plot new line:
 ## par (mfrow = c(1,2))
 ## plot(sh_cline, ispec = 1, main = "Updated Segmented hull", 
-##      subset = c(500,800))
+##      xlim = c(300,800))
 ## #plot new band depth
-## plot(sh_bd, ispec = 1, main="Updated hull - Band depth",
-##      subset = c(500,800))
+## plot(sh_bd[1,], main="Updated hull - Band depth",
+##      xlim = c(300,800))
 
 
 ###################################################
-### code chunk number 66: Hsdar-intro.Rnw:888-894
+### code chunk number 68: Hsdar-intro.Rnw:909-915
 ###################################################
 par(mfrow=c(1,2), mar = c(4,4,3,0.1), cex = 0.75)
 plot(sh_cline, ispec = 1, main = "Updated Segmented hull", 
-     subset = c(500,800))
+     xlim = c(300,800))
 #plot new band depth
-plot(sh_bd, ispec = 1, main="Updated hull - Band depth",
-     subset = c(500,800))
+plot(sh_bd[1,], main="Updated hull - Band depth",
+     xlim = c(300,800))
 
 
 ###################################################
-### code chunk number 67: Hsdar-intro.Rnw:900-936 (eval = FALSE)
+### code chunk number 69: Hsdar-intro.Rnw:921-957 (eval = FALSE)
 ###################################################
 ## data(spectral_data)
 ## 
@@ -718,7 +742,7 @@ plot(sh_bd, ispec = 1, main="Updated hull - Band depth",
 
 
 ###################################################
-### code chunk number 68: Hsdar-intro.Rnw:944-955
+### code chunk number 70: Hsdar-intro.Rnw:965-976
 ###################################################
 sh_bd <- transformSpeclib(spectral_data_preproc,
                           method = "sh", out = "bd")
@@ -734,14 +758,14 @@ plot(featureSelection, 1:4)
 
 
 ###################################################
-### code chunk number 69: Hsdar-intro.Rnw:958-960
+### code chunk number 71: Hsdar-intro.Rnw:979-981
 ###################################################
 par(mar = c(4,4,0.1,0.1), cex = 0.75)
 plot(featureSelection, 1:4)
 
 
 ###################################################
-### code chunk number 70: Hsdar-intro.Rnw:968-973
+### code chunk number 72: Hsdar-intro.Rnw:989-994
 ###################################################
 featuresCut <- cut_specfeat(featureSelection, fnumber = c(1,2), 
                             limits = c(c(310, 560), c(589, 800)))
@@ -751,14 +775,14 @@ plot(featuresCut, 1:2)
 
 
 ###################################################
-### code chunk number 71: Hsdar-intro.Rnw:976-978
+### code chunk number 73: Hsdar-intro.Rnw:997-999
 ###################################################
 par(mar = c(4,4,0.1,0.1), cex = 0.75)
 plot(featuresCut, 1:2)
 
 
 ###################################################
-### code chunk number 72: Hsdar-intro.Rnw:992-995
+### code chunk number 74: Hsdar-intro.Rnw:1013-1016
 ###################################################
 #split into subsets:
 sp_spring <- subset(spectral_data, season == "spring")
@@ -766,7 +790,7 @@ sp_summer <- subset(spectral_data, season == "summer")
 
 
 ###################################################
-### code chunk number 73: Hsdar-intro.Rnw:1015-1018 (eval = FALSE)
+### code chunk number 75: Hsdar-intro.Rnw:1036-1039 (eval = FALSE)
 ###################################################
 ## boxplot(spectra(sp_spring)[,wavelength(sp_spring) == 750],
 ##         spectra(sp_summer)[,wavelength(sp_summer) == 750],
@@ -774,7 +798,7 @@ sp_summer <- subset(spectral_data, season == "summer")
 
 
 ###################################################
-### code chunk number 74: Hsdar-intro.Rnw:1021-1025
+### code chunk number 76: Hsdar-intro.Rnw:1042-1046
 ###################################################
 par(mar = c(4,4,0.1,0.1), cex = 0.75)
 boxplot(spectra(sp_spring)[,wavelength(sp_spring) == 750],
@@ -783,7 +807,7 @@ boxplot(spectra(sp_spring)[,wavelength(sp_spring) == 750],
 
 
 ###################################################
-### code chunk number 75: Hsdar-intro.Rnw:1036-1043
+### code chunk number 77: Hsdar-intro.Rnw:1057-1064
 ###################################################
 result <- list()
 for (i in 1:length(wavelength(spectral_data)))
@@ -795,13 +819,19 @@ names(result) <- wavelength(spectral_data)
 
 
 ###################################################
-### code chunk number 76: Hsdar-intro.Rnw:1048-1049
+### code chunk number 78: Hsdar-intro.Rnw:1069-1070 (eval = FALSE)
+###################################################
+## result$"650"
+
+
+###################################################
+### code chunk number 79: Hsdar-intro.Rnw:1073-1074
 ###################################################
 result$"650"
 
 
 ###################################################
-### code chunk number 77: Hsdar-intro.Rnw:1054-1057 (eval = FALSE)
+### code chunk number 80: Hsdar-intro.Rnw:1080-1083 (eval = FALSE)
 ###################################################
 ## plot(attribute(spectral_data)$chlorophyll, 
 ##      spectra(spectral_data)[,wavelength(spectral_data)==650],
@@ -809,7 +839,7 @@ result$"650"
 
 
 ###################################################
-### code chunk number 78: Hsdar-intro.Rnw:1060-1064
+### code chunk number 81: Hsdar-intro.Rnw:1086-1090
 ###################################################
 par(mar = c(4,4,0.1,0.1), cex = 0.75)
 plot(attribute(spectral_data)$chlorophyll, 
@@ -818,7 +848,7 @@ plot(attribute(spectral_data)$chlorophyll,
 
 
 ###################################################
-### code chunk number 79: Hsdar-intro.Rnw:1077-1080
+### code chunk number 82: Hsdar-intro.Rnw:1103-1106
 ###################################################
 data(spectral_data)
 ndvi <- vegindex(spectral_data, "NDVI")
@@ -826,72 +856,72 @@ ndvi #see ndvi
 
 
 ###################################################
-### code chunk number 80: Hsdar-intro.Rnw:1086-1088
+### code chunk number 83: Hsdar-intro.Rnw:1112-1114
 ###################################################
 avl <- vegindex()
 vi <- vegindex(spectral_data, index = avl)
 
 
 ###################################################
-### code chunk number 81: Hsdar-intro.Rnw:1105-1107
+### code chunk number 84: Hsdar-intro.Rnw:1131-1133
 ###################################################
 data(spectral_data)
 rd <- rededge(spectral_data)
 
 
 ###################################################
-### code chunk number 82: Hsdar-intro.Rnw:1112-1113 (eval = FALSE)
+### code chunk number 85: Hsdar-intro.Rnw:1138-1139 (eval = FALSE)
 ###################################################
 ## boxplot(rd$R0 ~ spectral_data$attributes$season, ylab = "R0")
 
 
 ###################################################
-### code chunk number 83: Hsdar-intro.Rnw:1116-1118
+### code chunk number 86: Hsdar-intro.Rnw:1142-1144
 ###################################################
 par(mar = c(4,4,0.1,0.1), cex = 0.75)
 boxplot(rd$R0 ~ spectral_data$attributes$season, ylab = "R0")
 
 
 ###################################################
-### code chunk number 84: Hsdar-intro.Rnw:1134-1136
+### code chunk number 87: Hsdar-intro.Rnw:1160-1162
 ###################################################
 spec_WV <- spectralResampling(spectral_data, "WorldView2-8",
                               response_function = FALSE)
 
 
 ###################################################
-### code chunk number 85: Hsdar-intro.Rnw:1141-1142
+### code chunk number 88: Hsdar-intro.Rnw:1167-1168
 ###################################################
 str(nri)
 
 
 ###################################################
-### code chunk number 86: Hsdar-intro.Rnw:1144-1145 (eval = FALSE)
+### code chunk number 89: Hsdar-intro.Rnw:1170-1171 (eval = FALSE)
 ###################################################
 ## help(nri)
 
 
 ###################################################
-### code chunk number 87: Hsdar-intro.Rnw:1150-1152
+### code chunk number 90: Hsdar-intro.Rnw:1176-1178
 ###################################################
 nri_WV <- nri(spec_WV, recursive = TRUE)
 nri_WV
 
 
 ###################################################
-### code chunk number 88: Hsdar-intro.Rnw:1157-1158 (eval = FALSE)
+### code chunk number 91: Hsdar-intro.Rnw:1183-1184 (eval = FALSE)
 ###################################################
 ## str(nri_WV)
 
 
 ###################################################
-### code chunk number 89: Hsdar-intro.Rnw:1163-1164
+### code chunk number 92: Hsdar-intro.Rnw:1189-1190
 ###################################################
 nri_WV$nri[,,1] 
 
 
 ###################################################
-### code chunk number 90: Hsdar-intro.Rnw:1180-1183
+### code chunk number 93: Hsdar-intro.Rnw:1206-1209
 ###################################################
 spec_WV <- spectralResampling(spectral_data, "WorldView2-8",
                               response_function = FALSE)
@@ -899,108 +929,108 @@ nri_WV <- nri(spec_WV, recursive = TRUE)
 
 
 ###################################################
-### code chunk number 91: Hsdar-intro.Rnw:1191-1192
+### code chunk number 94: Hsdar-intro.Rnw:1217-1218
 ###################################################
 chlorophyll <- attribute(spec_WV)$chlorophyll
 
 
 ###################################################
-### code chunk number 92: Hsdar-intro.Rnw:1197-1198
+### code chunk number 95: Hsdar-intro.Rnw:1223-1224
 ###################################################
 cortestnri <- cor.test(nri_WV, chlorophyll)
 
 
 ###################################################
-### code chunk number 93: Hsdar-intro.Rnw:1203-1204
+### code chunk number 96: Hsdar-intro.Rnw:1229-1230
 ###################################################
 cortestnri
 
 
 ###################################################
-### code chunk number 94: Hsdar-intro.Rnw:1210-1211 (eval = FALSE)
+### code chunk number 97: Hsdar-intro.Rnw:1236-1237 (eval = FALSE)
 ###################################################
 ## plot(cortestnri, coefficient = "p.value")
 
 
 ###################################################
-### code chunk number 95: Hsdar-intro.Rnw:1214-1216
+### code chunk number 98: Hsdar-intro.Rnw:1240-1242
 ###################################################
 par(mar = c(4,4,0.1,0.1), cex = 0.75)
 plot(cortestnri, coefficient = "p.value")
 
 
 ###################################################
-### code chunk number 96: Hsdar-intro.Rnw:1223-1224 (eval = FALSE)
+### code chunk number 99: Hsdar-intro.Rnw:1249-1250 (eval = FALSE)
 ###################################################
 ## plot(cortestnri, coefficient = "p.value", range = c(0,0.01))
 
 
 ###################################################
-### code chunk number 97: Hsdar-intro.Rnw:1227-1229
+### code chunk number 100: Hsdar-intro.Rnw:1253-1255
 ###################################################
 par(mar = c(4,4,0.1,0.1), cex = 0.75)
 plot(cortestnri, coefficient = "p.value", range = c(0,0.01))
 
 
 ###################################################
-### code chunk number 98: Hsdar-intro.Rnw:1241-1242
+### code chunk number 101: Hsdar-intro.Rnw:1267-1268
 ###################################################
 str(lm.nri)
 
 
 ###################################################
-### code chunk number 99: Hsdar-intro.Rnw:1248-1249
+### code chunk number 102: Hsdar-intro.Rnw:1274-1275
 ###################################################
 lmnri <- lm.nri(nri_WV ~ chlorophyll, preddata = spec_WV)
 
 
 ###################################################
-### code chunk number 100: Hsdar-intro.Rnw:1254-1255
+### code chunk number 103: Hsdar-intro.Rnw:1280-1281
 ###################################################
 lmnri
 
 
 ###################################################
-### code chunk number 101: Hsdar-intro.Rnw:1261-1262
+### code chunk number 104: Hsdar-intro.Rnw:1287-1288
 ###################################################
 str(nri_best_performance)
 
 
 ###################################################
-### code chunk number 102: Hsdar-intro.Rnw:1269-1271
+### code chunk number 105: Hsdar-intro.Rnw:1295-1297
 ###################################################
 nribest <- nri_best_performance(lmnri, n = 1)
 nribest
 
 
 ###################################################
-### code chunk number 103: Hsdar-intro.Rnw:1277-1278
+### code chunk number 106: Hsdar-intro.Rnw:1303-1304
 ###################################################
 getNRI(nri_WV, nribest)
 
 
 ###################################################
-### code chunk number 104: Hsdar-intro.Rnw:1292-1293 (eval = FALSE)
+### code chunk number 107: Hsdar-intro.Rnw:1318-1319 (eval = FALSE)
 ###################################################
 ## plot(lmnri, coefficient = "r.squared", main = "R squared")
 
 
 ###################################################
-### code chunk number 105: Hsdar-intro.Rnw:1296-1298
+### code chunk number 108: Hsdar-intro.Rnw:1322-1324
 ###################################################
 par(mar = c(4,4,3,0.1), cex = 0.75)
 plot(lmnri, coefficient = "r.squared", main = "R squared")
 
 
 ###################################################
-### code chunk number 106: Hsdar-intro.Rnw:1305-1307 (eval = FALSE)
+### code chunk number 109: Hsdar-intro.Rnw:1331-1333 (eval = FALSE)
 ###################################################
 ## plot(lmnri, coefficient = "r.squared", main = "R squared",
 ##      constraint = "p.value<0.01")
 
 
 ###################################################
-### code chunk number 107: Hsdar-intro.Rnw:1310-1313
+### code chunk number 110: Hsdar-intro.Rnw:1336-1339
 ###################################################
 par(mar = c(4,4,3,0.1), cex = 0.75)
 plot(lmnri, coefficient = "r.squared", main = "R squared",
@@ -1008,7 +1038,7 @@ plot(lmnri, coefficient = "r.squared", main = "R squared",
 
 
 ###################################################
-### code chunk number 108: Hsdar-intro.Rnw:1325-1332
+### code chunk number 111: Hsdar-intro.Rnw:1351-1358
 ###################################################
 ## Use PROSAIL to generate some vegetation spectra with different LAI
 parameter <- data.frame(LAI = seq(0, 1, 0.01))
@@ -1020,7 +1050,7 @@ spectral_data_qb <- spectralResampling(spectral_data, "Quickbird")
 
 
 ###################################################
-### code chunk number 109: Hsdar-intro.Rnw:1337-1351 (eval = FALSE)
+### code chunk number 112: Hsdar-intro.Rnw:1363-1377 (eval = FALSE)
 ###################################################
 ## ## Get endmember spectra
 ## ## Retrieve all available spectra
@@ -1039,14 +1069,14 @@ spectral_data_qb <- spectralResampling(spectral_data, "Quickbird")
 
 
 ###################################################
-### code chunk number 110: Hsdar-intro.Rnw:1353-1355
+### code chunk number 113: Hsdar-intro.Rnw:1379-1381
 ###################################################
 grass_spectra_qb <- speclib(spectra = matrix(c(3.190627, 5.137504, 5.797486, 29.68515), nrow = 1), wavelength = c(485, 560, 660, 830))
 limestone_qb <- speclib(spectra = matrix(c(16.93489, 18.97302, 21.407, 23.98981), nrow = 1), wavelength = c(485, 560, 660, 830))
 
 
 ###################################################
-### code chunk number 111: Hsdar-intro.Rnw:1361-1368
+### code chunk number 114: Hsdar-intro.Rnw:1387-1394
 ###################################################
 em <- speclib(spectra = rbind(spectra(grass_spectra_qb),
                               spectra(limestone_qb))/100,
@@ -1058,7 +1088,7 @@ str(unmix_res)
 
 
 ###################################################
-### code chunk number 112: Hsdar-intro.Rnw:1380-1383
+### code chunk number 115: Hsdar-intro.Rnw:1406-1409
 ###################################################
 plot(unmix_res$fractions[1,] ~ attribute(spectral_data_qb)$LAI,
      type = "l", xlab = "LAI", 
@@ -1066,7 +1096,7 @@ plot(unmix_res$fractions[1,] ~ attribute(spectral_data_qb)$LAI,
 
 
 ###################################################
-### code chunk number 113: Hsdar-intro.Rnw:1386-1389
+### code chunk number 116: Hsdar-intro.Rnw:1412-1415
 ###################################################
 par(mar = c(4,4,0,0.1), cex = 0.75)
 plot(unmix_res$fractions[1,] ~ attribute(spectral_data_qb)$LAI, type = "l",
